@@ -3,14 +3,14 @@ from .version import __version__
 from os import path, environ
 
 try:
-    if path.exists(environ.get('API_SPEC_PATH')):
+    if path.exists(environ.get("PHARUS_SPEC_PATH")):
         dynamic_api_gen.populate_api()
 except TypeError:
-    print('No Dynamic API path found')
+    print("No Dynamic API path found")
 
 try:
     from .dynamic_api import app
 except ImportError:
     from .server import app
 
-__all__ = ['__version__', 'app']
+__all__ = ["__version__", "app"]
